"""
Type annotations for qbusiness service literal definitions.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/literals/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from types_boto3_qbusiness.literals import APISchemaTypeType

    data: APISchemaTypeType = "OPEN_API_V3"
    ```
"""

import sys

if sys.version_info >= (3, 12):
    from typing import Literal
else:
    from typing_extensions import Literal

__all__ = (
    "APISchemaTypeType",
    "ActionPayloadFieldTypeType",
    "ApplicationStatusType",
    "AttachmentStatusType",
    "AttachmentsControlModeType",
    "AttributeTypeType",
    "AttributeValueOperatorType",
    "AudioExtractionStatusType",
    "AudioExtractionTypeType",
    "AutoSubscriptionStatusType",
    "BrowserExtensionType",
    "ChatModeType",
    "ContentTypeType",
    "CreatorModeControlType",
    "DataSourceStatusType",
    "DataSourceSyncJobStatusType",
    "DocumentAttributeBoostingLevelType",
    "DocumentContentOperatorType",
    "DocumentEnrichmentConditionOperatorType",
    "DocumentStatusType",
    "ErrorCodeType",
    "GetChatControlsConfigurationPaginatorName",
    "GroupStatusType",
    "HallucinationReductionControlType",
    "IdentityTypeType",
    "ImageExtractionStatusType",
    "IndexStatusType",
    "IndexTypeType",
    "ListApplicationsPaginatorName",
    "ListAttachmentsPaginatorName",
    "ListConversationsPaginatorName",
    "ListDataAccessorsPaginatorName",
    "ListDataSourceSyncJobsPaginatorName",
    "ListDataSourcesPaginatorName",
    "ListDocumentsPaginatorName",
    "ListGroupsPaginatorName",
    "ListIndicesPaginatorName",
    "ListMessagesPaginatorName",
    "ListPluginActionsPaginatorName",
    "ListPluginTypeActionsPaginatorName",
    "ListPluginTypeMetadataPaginatorName",
    "ListPluginsPaginatorName",
    "ListRetrieversPaginatorName",
    "ListSubscriptionsPaginatorName",
    "ListWebExperiencesPaginatorName",
    "MemberRelationType",
    "MembershipTypeType",
    "MessageTypeType",
    "MessageUsefulnessReasonType",
    "MessageUsefulnessType",
    "NumberAttributeBoostingTypeType",
    "OrchestrationControlType",
    "PaginatorName",
    "PersonalizationControlModeType",
    "PluginBuildStatusType",
    "PluginStateType",
    "PluginTypeCategoryType",
    "PluginTypeType",
    "QAppsControlModeType",
    "QBusinessServiceName",
    "ReadAccessTypeType",
    "RegionName",
    "ResourceServiceName",
    "ResponseScopeType",
    "RetrieverStatusType",
    "RetrieverTypeType",
    "RuleTypeType",
    "ScoreConfidenceType",
    "SearchRelevantContentPaginatorName",
    "ServiceName",
    "StatusType",
    "StringAttributeValueBoostingLevelType",
    "SubscriptionTypeType",
    "SystemMessageTypeType",
    "VideoExtractionStatusType",
    "VideoExtractionTypeType",
    "WebExperienceSamplePromptsControlModeType",
    "WebExperienceStatusType",
)

APISchemaTypeType = Literal["OPEN_API_V3"]
ActionPayloadFieldTypeType = Literal["ARRAY", "BOOLEAN", "NUMBER", "STRING"]
ApplicationStatusType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
AttachmentStatusType = Literal["FAILED", "SUCCESS"]
AttachmentsControlModeType = Literal["DISABLED", "ENABLED"]
AttributeTypeType = Literal["DATE", "NUMBER", "STRING", "STRING_LIST"]
AttributeValueOperatorType = Literal["DELETE"]
AudioExtractionStatusType = Literal["DISABLED", "ENABLED"]
AudioExtractionTypeType = Literal["SUMMARY", "TRANSCRIPT"]
AutoSubscriptionStatusType = Literal["DISABLED", "ENABLED"]
BrowserExtensionType = Literal["CHROME", "FIREFOX"]
ChatModeType = Literal["CREATOR_MODE", "PLUGIN_MODE", "RETRIEVAL_MODE"]
ContentTypeType = Literal[
    "CSV",
    "HTML",
    "JSON",
    "MD",
    "MS_EXCEL",
    "MS_WORD",
    "PDF",
    "PLAIN_TEXT",
    "PPT",
    "RTF",
    "XML",
    "XSLT",
]
CreatorModeControlType = Literal["DISABLED", "ENABLED"]
DataSourceStatusType = Literal[
    "ACTIVE", "CREATING", "DELETING", "FAILED", "PENDING_CREATION", "UPDATING"
]
DataSourceSyncJobStatusType = Literal[
    "ABORTED", "FAILED", "INCOMPLETE", "STOPPING", "SUCCEEDED", "SYNCING", "SYNCING_INDEXING"
]
DocumentAttributeBoostingLevelType = Literal["HIGH", "LOW", "MEDIUM", "NONE", "VERY_HIGH"]
DocumentContentOperatorType = Literal["DELETE"]
DocumentEnrichmentConditionOperatorType = Literal[
    "BEGINS_WITH",
    "CONTAINS",
    "EQUALS",
    "EXISTS",
    "GREATER_THAN",
    "GREATER_THAN_OR_EQUALS",
    "LESS_THAN",
    "LESS_THAN_OR_EQUALS",
    "NOT_CONTAINS",
    "NOT_EQUALS",
    "NOT_EXISTS",
]
DocumentStatusType = Literal[
    "DELETED",
    "DELETING",
    "DOCUMENT_FAILED_TO_INDEX",
    "FAILED",
    "INDEXED",
    "PROCESSING",
    "RECEIVED",
    "UPDATED",
]
ErrorCodeType = Literal["InternalError", "InvalidRequest", "ResourceInactive", "ResourceNotFound"]
GetChatControlsConfigurationPaginatorName = Literal["get_chat_controls_configuration"]
GroupStatusType = Literal["DELETED", "DELETING", "FAILED", "PROCESSING", "SUCCEEDED"]
HallucinationReductionControlType = Literal["DISABLED", "ENABLED"]
IdentityTypeType = Literal[
    "ANONYMOUS", "AWS_IAM_IDC", "AWS_IAM_IDP_OIDC", "AWS_IAM_IDP_SAML", "AWS_QUICKSIGHT_IDP"
]
ImageExtractionStatusType = Literal["DISABLED", "ENABLED"]
IndexStatusType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "UPDATING"]
IndexTypeType = Literal["ENTERPRISE", "STARTER"]
ListApplicationsPaginatorName = Literal["list_applications"]
ListAttachmentsPaginatorName = Literal["list_attachments"]
ListConversationsPaginatorName = Literal["list_conversations"]
ListDataAccessorsPaginatorName = Literal["list_data_accessors"]
ListDataSourceSyncJobsPaginatorName = Literal["list_data_source_sync_jobs"]
ListDataSourcesPaginatorName = Literal["list_data_sources"]
ListDocumentsPaginatorName = Literal["list_documents"]
ListGroupsPaginatorName = Literal["list_groups"]
ListIndicesPaginatorName = Literal["list_indices"]
ListMessagesPaginatorName = Literal["list_messages"]
ListPluginActionsPaginatorName = Literal["list_plugin_actions"]
ListPluginTypeActionsPaginatorName = Literal["list_plugin_type_actions"]
ListPluginTypeMetadataPaginatorName = Literal["list_plugin_type_metadata"]
ListPluginsPaginatorName = Literal["list_plugins"]
ListRetrieversPaginatorName = Literal["list_retrievers"]
ListSubscriptionsPaginatorName = Literal["list_subscriptions"]
ListWebExperiencesPaginatorName = Literal["list_web_experiences"]
MemberRelationType = Literal["AND", "OR"]
MembershipTypeType = Literal["DATASOURCE", "INDEX"]
MessageTypeType = Literal["SYSTEM", "USER"]
MessageUsefulnessReasonType = Literal[
    "COMPLETE",
    "FACTUALLY_CORRECT",
    "HARMFUL_OR_UNSAFE",
    "HELPFUL",
    "INCORRECT_OR_MISSING_SOURCES",
    "NOT_BASED_ON_DOCUMENTS",
    "NOT_COMPLETE",
    "NOT_CONCISE",
    "NOT_FACTUALLY_CORRECT",
    "NOT_HELPFUL",
    "OTHER",
    "RELEVANT_SOURCES",
]
MessageUsefulnessType = Literal["NOT_USEFUL", "USEFUL"]
NumberAttributeBoostingTypeType = Literal["PRIORITIZE_LARGER_VALUES", "PRIORITIZE_SMALLER_VALUES"]
OrchestrationControlType = Literal["DISABLED", "ENABLED"]
PersonalizationControlModeType = Literal["DISABLED", "ENABLED"]
PluginBuildStatusType = Literal[
    "CREATE_FAILED",
    "CREATE_IN_PROGRESS",
    "DELETE_FAILED",
    "DELETE_IN_PROGRESS",
    "READY",
    "UPDATE_FAILED",
    "UPDATE_IN_PROGRESS",
]
PluginStateType = Literal["DISABLED", "ENABLED"]
PluginTypeCategoryType = Literal[
    "Communication",
    "Customer relationship management (CRM)",
    "Productivity",
    "Project management",
    "Ticketing and incident management",
]
PluginTypeType = Literal[
    "ASANA",
    "ATLASSIAN_CONFLUENCE",
    "CUSTOM",
    "GOOGLE_CALENDAR",
    "JIRA",
    "JIRA_CLOUD",
    "MICROSOFT_EXCHANGE",
    "MICROSOFT_TEAMS",
    "PAGERDUTY_ADVANCE",
    "QUICKSIGHT",
    "SALESFORCE",
    "SALESFORCE_CRM",
    "SERVICENOW_NOW_PLATFORM",
    "SERVICE_NOW",
    "SMARTSHEET",
    "ZENDESK",
    "ZENDESK_SUITE",
]
QAppsControlModeType = Literal["DISABLED", "ENABLED"]
ReadAccessTypeType = Literal["ALLOW", "DENY"]
ResponseScopeType = Literal["ENTERPRISE_CONTENT_ONLY", "EXTENDED_KNOWLEDGE_ENABLED"]
RetrieverStatusType = Literal["ACTIVE", "CREATING", "FAILED"]
RetrieverTypeType = Literal["KENDRA_INDEX", "NATIVE_INDEX"]
RuleTypeType = Literal["CONTENT_BLOCKER_RULE", "CONTENT_RETRIEVAL_RULE"]
ScoreConfidenceType = Literal["HIGH", "LOW", "MEDIUM", "NOT_AVAILABLE", "VERY_HIGH"]
SearchRelevantContentPaginatorName = Literal["search_relevant_content"]
StatusType = Literal["DISABLED", "ENABLED"]
StringAttributeValueBoostingLevelType = Literal["HIGH", "LOW", "MEDIUM", "VERY_HIGH"]
SubscriptionTypeType = Literal["Q_BUSINESS", "Q_LITE"]
SystemMessageTypeType = Literal["GROUNDED_RESPONSE", "RESPONSE"]
VideoExtractionStatusType = Literal["DISABLED", "ENABLED"]
VideoExtractionTypeType = Literal["SUMMARY", "TRANSCRIPT"]
WebExperienceSamplePromptsControlModeType = Literal["DISABLED", "ENABLED"]
WebExperienceStatusType = Literal["ACTIVE", "CREATING", "DELETING", "FAILED", "PENDING_AUTH_CONFIG"]
QBusinessServiceName = Literal["qbusiness"]
ServiceName = Literal[
    "accessanalyzer",
    "account",
    "acm",
    "acm-pca",
    "amp",
    "amplify",
    "amplifybackend",
    "amplifyuibuilder",
    "apigateway",
    "apigatewaymanagementapi",
    "apigatewayv2",
    "appconfig",
    "appconfigdata",
    "appfabric",
    "appflow",
    "appintegrations",
    "application-autoscaling",
    "application-insights",
    "application-signals",
    "applicationcostprofiler",
    "appmesh",
    "apprunner",
    "appstream",
    "appsync",
    "apptest",
    "arc-zonal-shift",
    "artifact",
    "athena",
    "auditmanager",
    "autoscaling",
    "autoscaling-plans",
    "b2bi",
    "backup",
    "backup-gateway",
    "backupsearch",
    "batch",
    "bcm-data-exports",
    "bcm-pricing-calculator",
    "bedrock",
    "bedrock-agent",
    "bedrock-agent-runtime",
    "bedrock-data-automation",
    "bedrock-data-automation-runtime",
    "bedrock-runtime",
    "billing",
    "billingconductor",
    "braket",
    "budgets",
    "ce",
    "chatbot",
    "chime",
    "chime-sdk-identity",
    "chime-sdk-media-pipelines",
    "chime-sdk-meetings",
    "chime-sdk-messaging",
    "chime-sdk-voice",
    "cleanrooms",
    "cleanroomsml",
    "cloud9",
    "cloudcontrol",
    "clouddirectory",
    "cloudformation",
    "cloudfront",
    "cloudfront-keyvaluestore",
    "cloudhsm",
    "cloudhsmv2",
    "cloudsearch",
    "cloudsearchdomain",
    "cloudtrail",
    "cloudtrail-data",
    "cloudwatch",
    "codeartifact",
    "codebuild",
    "codecatalyst",
    "codecommit",
    "codeconnections",
    "codedeploy",
    "codeguru-reviewer",
    "codeguru-security",
    "codeguruprofiler",
    "codepipeline",
    "codestar-connections",
    "codestar-notifications",
    "cognito-identity",
    "cognito-idp",
    "cognito-sync",
    "comprehend",
    "comprehendmedical",
    "compute-optimizer",
    "config",
    "connect",
    "connect-contact-lens",
    "connectcampaigns",
    "connectcampaignsv2",
    "connectcases",
    "connectparticipant",
    "controlcatalog",
    "controltower",
    "cost-optimization-hub",
    "cur",
    "customer-profiles",
    "databrew",
    "dataexchange",
    "datapipeline",
    "datasync",
    "datazone",
    "dax",
    "deadline",
    "detective",
    "devicefarm",
    "devops-guru",
    "directconnect",
    "discovery",
    "dlm",
    "dms",
    "docdb",
    "docdb-elastic",
    "drs",
    "ds",
    "ds-data",
    "dsql",
    "dynamodb",
    "dynamodbstreams",
    "ebs",
    "ec2",
    "ec2-instance-connect",
    "ecr",
    "ecr-public",
    "ecs",
    "efs",
    "eks",
    "eks-auth",
    "elasticache",
    "elasticbeanstalk",
    "elastictranscoder",
    "elb",
    "elbv2",
    "emr",
    "emr-containers",
    "emr-serverless",
    "entityresolution",
    "es",
    "events",
    "evidently",
    "finspace",
    "finspace-data",
    "firehose",
    "fis",
    "fms",
    "forecast",
    "forecastquery",
    "frauddetector",
    "freetier",
    "fsx",
    "gamelift",
    "gameliftstreams",
    "geo-maps",
    "geo-places",
    "geo-routes",
    "glacier",
    "globalaccelerator",
    "glue",
    "grafana",
    "greengrass",
    "greengrassv2",
    "groundstation",
    "guardduty",
    "health",
    "healthlake",
    "iam",
    "identitystore",
    "imagebuilder",
    "importexport",
    "inspector",
    "inspector-scan",
    "inspector2",
    "internetmonitor",
    "invoicing",
    "iot",
    "iot-data",
    "iot-jobs-data",
    "iot-managed-integrations",
    "iotanalytics",
    "iotdeviceadvisor",
    "iotevents",
    "iotevents-data",
    "iotfleethub",
    "iotfleetwise",
    "iotsecuretunneling",
    "iotsitewise",
    "iotthingsgraph",
    "iottwinmaker",
    "iotwireless",
    "ivs",
    "ivs-realtime",
    "ivschat",
    "kafka",
    "kafkaconnect",
    "kendra",
    "kendra-ranking",
    "keyspaces",
    "kinesis",
    "kinesis-video-archived-media",
    "kinesis-video-media",
    "kinesis-video-signaling",
    "kinesis-video-webrtc-storage",
    "kinesisanalytics",
    "kinesisanalyticsv2",
    "kinesisvideo",
    "kms",
    "lakeformation",
    "lambda",
    "launch-wizard",
    "lex-models",
    "lex-runtime",
    "lexv2-models",
    "lexv2-runtime",
    "license-manager",
    "license-manager-linux-subscriptions",
    "license-manager-user-subscriptions",
    "lightsail",
    "location",
    "logs",
    "lookoutequipment",
    "lookoutmetrics",
    "lookoutvision",
    "m2",
    "machinelearning",
    "macie2",
    "mailmanager",
    "managedblockchain",
    "managedblockchain-query",
    "marketplace-agreement",
    "marketplace-catalog",
    "marketplace-deployment",
    "marketplace-entitlement",
    "marketplace-reporting",
    "marketplacecommerceanalytics",
    "mediaconnect",
    "mediaconvert",
    "medialive",
    "mediapackage",
    "mediapackage-vod",
    "mediapackagev2",
    "mediastore",
    "mediastore-data",
    "mediatailor",
    "medical-imaging",
    "memorydb",
    "meteringmarketplace",
    "mgh",
    "mgn",
    "migration-hub-refactor-spaces",
    "migrationhub-config",
    "migrationhuborchestrator",
    "migrationhubstrategy",
    "mq",
    "mturk",
    "mwaa",
    "neptune",
    "neptune-graph",
    "neptunedata",
    "network-firewall",
    "networkflowmonitor",
    "networkmanager",
    "networkmonitor",
    "notifications",
    "notificationscontacts",
    "oam",
    "observabilityadmin",
    "omics",
    "opensearch",
    "opensearchserverless",
    "opsworks",
    "opsworkscm",
    "organizations",
    "osis",
    "outposts",
    "panorama",
    "partnercentral-selling",
    "payment-cryptography",
    "payment-cryptography-data",
    "pca-connector-ad",
    "pca-connector-scep",
    "pcs",
    "personalize",
    "personalize-events",
    "personalize-runtime",
    "pi",
    "pinpoint",
    "pinpoint-email",
    "pinpoint-sms-voice",
    "pinpoint-sms-voice-v2",
    "pipes",
    "polly",
    "pricing",
    "privatenetworks",
    "proton",
    "qapps",
    "qbusiness",
    "qconnect",
    "qldb",
    "qldb-session",
    "quicksight",
    "ram",
    "rbin",
    "rds",
    "rds-data",
    "redshift",
    "redshift-data",
    "redshift-serverless",
    "rekognition",
    "repostspace",
    "resiliencehub",
    "resource-explorer-2",
    "resource-groups",
    "resourcegroupstaggingapi",
    "robomaker",
    "rolesanywhere",
    "route53",
    "route53-recovery-cluster",
    "route53-recovery-control-config",
    "route53-recovery-readiness",
    "route53domains",
    "route53profiles",
    "route53resolver",
    "rum",
    "s3",
    "s3control",
    "s3outposts",
    "s3tables",
    "sagemaker",
    "sagemaker-a2i-runtime",
    "sagemaker-edge",
    "sagemaker-featurestore-runtime",
    "sagemaker-geospatial",
    "sagemaker-metrics",
    "sagemaker-runtime",
    "savingsplans",
    "scheduler",
    "schemas",
    "sdb",
    "secretsmanager",
    "security-ir",
    "securityhub",
    "securitylake",
    "serverlessrepo",
    "service-quotas",
    "servicecatalog",
    "servicecatalog-appregistry",
    "servicediscovery",
    "ses",
    "sesv2",
    "shield",
    "signer",
    "simspaceweaver",
    "sms",
    "sms-voice",
    "snow-device-management",
    "snowball",
    "sns",
    "socialmessaging",
    "sqs",
    "ssm",
    "ssm-contacts",
    "ssm-guiconnect",
    "ssm-incidents",
    "ssm-quicksetup",
    "ssm-sap",
    "sso",
    "sso-admin",
    "sso-oidc",
    "stepfunctions",
    "storagegateway",
    "sts",
    "supplychain",
    "support",
    "support-app",
    "swf",
    "synthetics",
    "taxsettings",
    "textract",
    "timestream-influxdb",
    "timestream-query",
    "timestream-write",
    "tnb",
    "transcribe",
    "transfer",
    "translate",
    "trustedadvisor",
    "verifiedpermissions",
    "voice-id",
    "vpc-lattice",
    "waf",
    "waf-regional",
    "wafv2",
    "wellarchitected",
    "wisdom",
    "workdocs",
    "workmail",
    "workmailmessageflow",
    "workspaces",
    "workspaces-thin-client",
    "workspaces-web",
    "xray",
]
ResourceServiceName = Literal[
    "cloudformation",
    "cloudwatch",
    "dynamodb",
    "ec2",
    "glacier",
    "iam",
    "opsworks",
    "s3",
    "sns",
    "sqs",
]
PaginatorName = Literal[
    "get_chat_controls_configuration",
    "list_applications",
    "list_attachments",
    "list_conversations",
    "list_data_accessors",
    "list_data_source_sync_jobs",
    "list_data_sources",
    "list_documents",
    "list_groups",
    "list_indices",
    "list_messages",
    "list_plugin_actions",
    "list_plugin_type_actions",
    "list_plugin_type_metadata",
    "list_plugins",
    "list_retrievers",
    "list_subscriptions",
    "list_web_experiences",
    "search_relevant_content",
]
RegionName = Literal[
    "af-south-1",
    "ap-east-1",
    "ap-northeast-1",
    "ap-northeast-2",
    "ap-northeast-3",
    "ap-south-1",
    "ap-south-2",
    "ap-southeast-1",
    "ap-southeast-2",
    "ap-southeast-3",
    "ap-southeast-4",
    "ap-southeast-5",
    "ap-southeast-7",
    "ca-central-1",
    "ca-west-1",
    "eu-central-1",
    "eu-central-2",
    "eu-north-1",
    "eu-south-1",
    "eu-south-2",
    "eu-west-1",
    "eu-west-2",
    "eu-west-3",
    "il-central-1",
    "me-central-1",
    "me-south-1",
    "mx-central-1",
    "sa-east-1",
    "us-east-1",
    "us-east-2",
    "us-west-1",
    "us-west-2",
]



"""
Type annotations for qbusiness service Client.

[Documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/)

Copyright 2025 Vlad Emelianov

Usage::

    ```python
    from boto3.session import Session
    from types_boto3_qbusiness.client import QBusinessClient

    session = Session()
    client: QBusinessClient = session.client("qbusiness")
    ```
"""

from __future__ import annotations

import sys
from typing import Any, overload

from botocore.client import BaseClient, ClientMeta
from botocore.errorfactory import BaseClientExceptions
from botocore.exceptions import ClientError as BotocoreClientError

from .paginator import (
    GetChatControlsConfigurationPaginator,
    ListApplicationsPaginator,
    ListAttachmentsPaginator,
    ListConversationsPaginator,
    ListDataAccessorsPaginator,
    ListDataSourcesPaginator,
    ListDataSourceSyncJobsPaginator,
    ListDocumentsPaginator,
    ListGroupsPaginator,
    ListIndicesPaginator,
    ListMessagesPaginator,
    ListPluginActionsPaginator,
    ListPluginsPaginator,
    ListPluginTypeActionsPaginator,
    ListPluginTypeMetadataPaginator,
    ListRetrieversPaginator,
    ListSubscriptionsPaginator,
    ListWebExperiencesPaginator,
    SearchRelevantContentPaginator,
)
from .type_defs import (
    AssociatePermissionRequestTypeDef,
    AssociatePermissionResponseTypeDef,
    BatchDeleteDocumentRequestTypeDef,
    BatchDeleteDocumentResponseTypeDef,
    BatchPutDocumentRequestTypeDef,
    BatchPutDocumentResponseTypeDef,
    CancelSubscriptionRequestTypeDef,
    CancelSubscriptionResponseTypeDef,
    ChatInputTypeDef,
    ChatOutputTypeDef,
    ChatSyncInputTypeDef,
    ChatSyncOutputTypeDef,
    CheckDocumentAccessRequestTypeDef,
    CheckDocumentAccessResponseTypeDef,
    CreateAnonymousWebExperienceUrlRequestTypeDef,
    CreateAnonymousWebExperienceUrlResponseTypeDef,
    CreateApplicationRequestTypeDef,
    CreateApplicationResponseTypeDef,
    CreateDataAccessorRequestTypeDef,
    CreateDataAccessorResponseTypeDef,
    CreateDataSourceRequestTypeDef,
    CreateDataSourceResponseTypeDef,
    CreateIndexRequestTypeDef,
    CreateIndexResponseTypeDef,
    CreatePluginRequestTypeDef,
    CreatePluginResponseTypeDef,
    CreateRetrieverRequestTypeDef,
    CreateRetrieverResponseTypeDef,
    CreateSubscriptionRequestTypeDef,
    CreateSubscriptionResponseTypeDef,
    CreateUserRequestTypeDef,
    CreateWebExperienceRequestTypeDef,
    CreateWebExperienceResponseTypeDef,
    DeleteApplicationRequestTypeDef,
    DeleteAttachmentRequestTypeDef,
    DeleteChatControlsConfigurationRequestTypeDef,
    DeleteConversationRequestTypeDef,
    DeleteDataAccessorRequestTypeDef,
    DeleteDataSourceRequestTypeDef,
    DeleteGroupRequestTypeDef,
    DeleteIndexRequestTypeDef,
    DeletePluginRequestTypeDef,
    DeleteRetrieverRequestTypeDef,
    DeleteUserRequestTypeDef,
    DeleteWebExperienceRequestTypeDef,
    DisassociatePermissionRequestTypeDef,
    EmptyResponseMetadataTypeDef,
    GetApplicationRequestTypeDef,
    GetApplicationResponseTypeDef,
    GetChatControlsConfigurationRequestTypeDef,
    GetChatControlsConfigurationResponseTypeDef,
    GetDataAccessorRequestTypeDef,
    GetDataAccessorResponseTypeDef,
    GetDataSourceRequestTypeDef,
    GetDataSourceResponseTypeDef,
    GetGroupRequestTypeDef,
    GetGroupResponseTypeDef,
    GetIndexRequestTypeDef,
    GetIndexResponseTypeDef,
    GetMediaRequestTypeDef,
    GetMediaResponseTypeDef,
    GetPluginRequestTypeDef,
    GetPluginResponseTypeDef,
    GetPolicyRequestTypeDef,
    GetPolicyResponseTypeDef,
    GetRetrieverRequestTypeDef,
    GetRetrieverResponseTypeDef,
    GetUserRequestTypeDef,
    GetUserResponseTypeDef,
    GetWebExperienceRequestTypeDef,
    GetWebExperienceResponseTypeDef,
    ListApplicationsRequestTypeDef,
    ListApplicationsResponseTypeDef,
    ListAttachmentsRequestTypeDef,
    ListAttachmentsResponseTypeDef,
    ListConversationsRequestTypeDef,
    ListConversationsResponseTypeDef,
    ListDataAccessorsRequestTypeDef,
    ListDataAccessorsResponseTypeDef,
    ListDataSourcesRequestTypeDef,
    ListDataSourcesResponseTypeDef,
    ListDataSourceSyncJobsRequestTypeDef,
    ListDataSourceSyncJobsResponseTypeDef,
    ListDocumentsRequestTypeDef,
    ListDocumentsResponseTypeDef,
    ListGroupsRequestTypeDef,
    ListGroupsResponseTypeDef,
    ListIndicesRequestTypeDef,
    ListIndicesResponseTypeDef,
    ListMessagesRequestTypeDef,
    ListMessagesResponseTypeDef,
    ListPluginActionsRequestTypeDef,
    ListPluginActionsResponseTypeDef,
    ListPluginsRequestTypeDef,
    ListPluginsResponseTypeDef,
    ListPluginTypeActionsRequestTypeDef,
    ListPluginTypeActionsResponseTypeDef,
    ListPluginTypeMetadataRequestTypeDef,
    ListPluginTypeMetadataResponseTypeDef,
    ListRetrieversRequestTypeDef,
    ListRetrieversResponseTypeDef,
    ListSubscriptionsRequestTypeDef,
    ListSubscriptionsResponseTypeDef,
    ListTagsForResourceRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    ListWebExperiencesRequestTypeDef,
    ListWebExperiencesResponseTypeDef,
    PutFeedbackRequestTypeDef,
    PutGroupRequestTypeDef,
    SearchRelevantContentRequestTypeDef,
    SearchRelevantContentResponseTypeDef,
    StartDataSourceSyncJobRequestTypeDef,
    StartDataSourceSyncJobResponseTypeDef,
    StopDataSourceSyncJobRequestTypeDef,
    TagResourceRequestTypeDef,
    UntagResourceRequestTypeDef,
    UpdateApplicationRequestTypeDef,
    UpdateChatControlsConfigurationRequestTypeDef,
    UpdateDataAccessorRequestTypeDef,
    UpdateDataSourceRequestTypeDef,
    UpdateIndexRequestTypeDef,
    UpdatePluginRequestTypeDef,
    UpdateRetrieverRequestTypeDef,
    UpdateSubscriptionRequestTypeDef,
    UpdateSubscriptionResponseTypeDef,
    UpdateUserRequestTypeDef,
    UpdateUserResponseTypeDef,
    UpdateWebExperienceRequestTypeDef,
)

if sys.version_info >= (3, 9):
    from builtins import dict as Dict
    from builtins import type as Type
    from collections.abc import Mapping
else:
    from typing import Dict, Mapping, Type
if sys.version_info >= (3, 12):
    from typing import Literal, Unpack
else:
    from typing_extensions import Literal, Unpack


__all__ = ("QBusinessClient",)


class Exceptions(BaseClientExceptions):
    AccessDeniedException: Type[BotocoreClientError]
    ClientError: Type[BotocoreClientError]
    ConflictException: Type[BotocoreClientError]
    ExternalResourceException: Type[BotocoreClientError]
    InternalServerException: Type[BotocoreClientError]
    LicenseNotFoundException: Type[BotocoreClientError]
    MediaTooLargeException: Type[BotocoreClientError]
    ResourceNotFoundException: Type[BotocoreClientError]
    ServiceQuotaExceededException: Type[BotocoreClientError]
    ThrottlingException: Type[BotocoreClientError]
    ValidationException: Type[BotocoreClientError]


class QBusinessClient(BaseClient):
    """
    [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness.html#QBusiness.Client)
    [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/)
    """

    meta: ClientMeta

    @property
    def exceptions(self) -> Exceptions:
        """
        QBusinessClient exceptions.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness.html#QBusiness.Client)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#exceptions)
        """

    def can_paginate(self, operation_name: str) -> bool:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/can_paginate.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#can_paginate)
        """

    def generate_presigned_url(
        self,
        ClientMethod: str,
        Params: Mapping[str, Any] = ...,
        ExpiresIn: int = 3600,
        HttpMethod: str = ...,
    ) -> str:
        """
        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/generate_presigned_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#generate_presigned_url)
        """

    def associate_permission(
        self, **kwargs: Unpack[AssociatePermissionRequestTypeDef]
    ) -> AssociatePermissionResponseTypeDef:
        """
        Adds or updates a permission policy for a Amazon Q Business application,
        allowing cross-account access for an ISV.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/associate_permission.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#associate_permission)
        """

    def batch_delete_document(
        self, **kwargs: Unpack[BatchDeleteDocumentRequestTypeDef]
    ) -> BatchDeleteDocumentResponseTypeDef:
        """
        Asynchronously deletes one or more documents added using the
        <code>BatchPutDocument</code> API from an Amazon Q Business index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/batch_delete_document.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#batch_delete_document)
        """

    def batch_put_document(
        self, **kwargs: Unpack[BatchPutDocumentRequestTypeDef]
    ) -> BatchPutDocumentResponseTypeDef:
        """
        Adds one or more documents to an Amazon Q Business index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/batch_put_document.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#batch_put_document)
        """

    def cancel_subscription(
        self, **kwargs: Unpack[CancelSubscriptionRequestTypeDef]
    ) -> CancelSubscriptionResponseTypeDef:
        """
        Unsubscribes a user or a group from their pricing tier in an Amazon Q Business
        application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/cancel_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#cancel_subscription)
        """

    def chat(self, **kwargs: Unpack[ChatInputTypeDef]) -> ChatOutputTypeDef:
        """
        Starts or continues a streaming Amazon Q Business conversation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/chat.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#chat)
        """

    def chat_sync(self, **kwargs: Unpack[ChatSyncInputTypeDef]) -> ChatSyncOutputTypeDef:
        """
        Starts or continues a non-streaming Amazon Q Business conversation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/chat_sync.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#chat_sync)
        """

    def check_document_access(
        self, **kwargs: Unpack[CheckDocumentAccessRequestTypeDef]
    ) -> CheckDocumentAccessResponseTypeDef:
        """
        Verifies if a user has access permissions for a specified document and returns
        the actual ACL attached to the document.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/check_document_access.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#check_document_access)
        """

    def create_anonymous_web_experience_url(
        self, **kwargs: Unpack[CreateAnonymousWebExperienceUrlRequestTypeDef]
    ) -> CreateAnonymousWebExperienceUrlResponseTypeDef:
        """
        Creates a unique URL for anonymous Amazon Q Business web experience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_anonymous_web_experience_url.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_anonymous_web_experience_url)
        """

    def create_application(
        self, **kwargs: Unpack[CreateApplicationRequestTypeDef]
    ) -> CreateApplicationResponseTypeDef:
        """
        Creates an Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_application.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_application)
        """

    def create_data_accessor(
        self, **kwargs: Unpack[CreateDataAccessorRequestTypeDef]
    ) -> CreateDataAccessorResponseTypeDef:
        """
        Creates a new data accessor for an ISV to access data from a Amazon Q Business
        application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_data_accessor.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_data_accessor)
        """

    def create_data_source(
        self, **kwargs: Unpack[CreateDataSourceRequestTypeDef]
    ) -> CreateDataSourceResponseTypeDef:
        """
        Creates a data source connector for an Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_data_source.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_data_source)
        """

    def create_index(
        self, **kwargs: Unpack[CreateIndexRequestTypeDef]
    ) -> CreateIndexResponseTypeDef:
        """
        Creates an Amazon Q Business index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_index.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_index)
        """

    def create_plugin(
        self, **kwargs: Unpack[CreatePluginRequestTypeDef]
    ) -> CreatePluginResponseTypeDef:
        """
        Creates an Amazon Q Business plugin.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_plugin.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_plugin)
        """

    def create_retriever(
        self, **kwargs: Unpack[CreateRetrieverRequestTypeDef]
    ) -> CreateRetrieverResponseTypeDef:
        """
        Adds a retriever to your Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_retriever.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_retriever)
        """

    def create_subscription(
        self, **kwargs: Unpack[CreateSubscriptionRequestTypeDef]
    ) -> CreateSubscriptionResponseTypeDef:
        """
        Subscribes an IAM Identity Center user or a group to a pricing tier for an
        Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_subscription)
        """

    def create_user(self, **kwargs: Unpack[CreateUserRequestTypeDef]) -> Dict[str, Any]:
        """
        Creates a universally unique identifier (UUID) mapped to a list of local user
        ids within an application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_user.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_user)
        """

    def create_web_experience(
        self, **kwargs: Unpack[CreateWebExperienceRequestTypeDef]
    ) -> CreateWebExperienceResponseTypeDef:
        """
        Creates an Amazon Q Business web experience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/create_web_experience.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#create_web_experience)
        """

    def delete_application(
        self, **kwargs: Unpack[DeleteApplicationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes an Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_application.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_application)
        """

    def delete_attachment(self, **kwargs: Unpack[DeleteAttachmentRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes an attachment associated with a specific Amazon Q Business conversation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_attachment.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_attachment)
        """

    def delete_chat_controls_configuration(
        self, **kwargs: Unpack[DeleteChatControlsConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes chat controls configured for an existing Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_chat_controls_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_chat_controls_configuration)
        """

    def delete_conversation(
        self, **kwargs: Unpack[DeleteConversationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes an Amazon Q Business web experience conversation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_conversation.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_conversation)
        """

    def delete_data_accessor(
        self, **kwargs: Unpack[DeleteDataAccessorRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes a specified data accessor.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_data_accessor.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_data_accessor)
        """

    def delete_data_source(
        self, **kwargs: Unpack[DeleteDataSourceRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes an Amazon Q Business data source connector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_data_source.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_data_source)
        """

    def delete_group(self, **kwargs: Unpack[DeleteGroupRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes a group so that all users and sub groups that belong to the group can
        no longer access documents only available to that group.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_group.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_group)
        """

    def delete_index(self, **kwargs: Unpack[DeleteIndexRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes an Amazon Q Business index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_index.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_index)
        """

    def delete_plugin(self, **kwargs: Unpack[DeletePluginRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes an Amazon Q Business plugin.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_plugin.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_plugin)
        """

    def delete_retriever(self, **kwargs: Unpack[DeleteRetrieverRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes the retriever used by an Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_retriever.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_retriever)
        """

    def delete_user(self, **kwargs: Unpack[DeleteUserRequestTypeDef]) -> Dict[str, Any]:
        """
        Deletes a user by email id.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_user.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_user)
        """

    def delete_web_experience(
        self, **kwargs: Unpack[DeleteWebExperienceRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Deletes an Amazon Q Business web experience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/delete_web_experience.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#delete_web_experience)
        """

    def disassociate_permission(
        self, **kwargs: Unpack[DisassociatePermissionRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Removes a permission policy from a Amazon Q Business application, revoking the
        cross-account access that was previously granted to an ISV.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/disassociate_permission.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#disassociate_permission)
        """

    def get_application(
        self, **kwargs: Unpack[GetApplicationRequestTypeDef]
    ) -> GetApplicationResponseTypeDef:
        """
        Gets information about an existing Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_application.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_application)
        """

    def get_chat_controls_configuration(
        self, **kwargs: Unpack[GetChatControlsConfigurationRequestTypeDef]
    ) -> GetChatControlsConfigurationResponseTypeDef:
        """
        Gets information about chat controls configured for an existing Amazon Q
        Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_chat_controls_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_chat_controls_configuration)
        """

    def get_data_accessor(
        self, **kwargs: Unpack[GetDataAccessorRequestTypeDef]
    ) -> GetDataAccessorResponseTypeDef:
        """
        Retrieves information about a specified data accessor.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_data_accessor.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_data_accessor)
        """

    def get_data_source(
        self, **kwargs: Unpack[GetDataSourceRequestTypeDef]
    ) -> GetDataSourceResponseTypeDef:
        """
        Gets information about an existing Amazon Q Business data source connector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_data_source.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_data_source)
        """

    def get_group(self, **kwargs: Unpack[GetGroupRequestTypeDef]) -> GetGroupResponseTypeDef:
        """
        Describes a group by group name.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_group.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_group)
        """

    def get_index(self, **kwargs: Unpack[GetIndexRequestTypeDef]) -> GetIndexResponseTypeDef:
        """
        Gets information about an existing Amazon Q Business index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_index.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_index)
        """

    def get_media(self, **kwargs: Unpack[GetMediaRequestTypeDef]) -> GetMediaResponseTypeDef:
        """
        Returns the image bytes corresponding to a media object.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_media.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_media)
        """

    def get_plugin(self, **kwargs: Unpack[GetPluginRequestTypeDef]) -> GetPluginResponseTypeDef:
        """
        Gets information about an existing Amazon Q Business plugin.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_plugin.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_plugin)
        """

    def get_policy(self, **kwargs: Unpack[GetPolicyRequestTypeDef]) -> GetPolicyResponseTypeDef:
        """
        Retrieves the current permission policy for a Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_policy.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_policy)
        """

    def get_retriever(
        self, **kwargs: Unpack[GetRetrieverRequestTypeDef]
    ) -> GetRetrieverResponseTypeDef:
        """
        Gets information about an existing retriever used by an Amazon Q Business
        application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_retriever.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_retriever)
        """

    def get_user(self, **kwargs: Unpack[GetUserRequestTypeDef]) -> GetUserResponseTypeDef:
        """
        Describes the universally unique identifier (UUID) associated with a local user
        in a data source.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_user.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_user)
        """

    def get_web_experience(
        self, **kwargs: Unpack[GetWebExperienceRequestTypeDef]
    ) -> GetWebExperienceResponseTypeDef:
        """
        Gets information about an existing Amazon Q Business web experience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_web_experience.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_web_experience)
        """

    def list_applications(
        self, **kwargs: Unpack[ListApplicationsRequestTypeDef]
    ) -> ListApplicationsResponseTypeDef:
        """
        Lists Amazon Q Business applications.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_applications.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_applications)
        """

    def list_attachments(
        self, **kwargs: Unpack[ListAttachmentsRequestTypeDef]
    ) -> ListAttachmentsResponseTypeDef:
        """
        Gets a list of attachments associated with an Amazon Q Business web experience
        or a list of attachements associated with a specific Amazon Q Business
        conversation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_attachments.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_attachments)
        """

    def list_conversations(
        self, **kwargs: Unpack[ListConversationsRequestTypeDef]
    ) -> ListConversationsResponseTypeDef:
        """
        Lists one or more Amazon Q Business conversations.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_conversations.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_conversations)
        """

    def list_data_accessors(
        self, **kwargs: Unpack[ListDataAccessorsRequestTypeDef]
    ) -> ListDataAccessorsResponseTypeDef:
        """
        Lists the data accessors for a Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_data_accessors.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_data_accessors)
        """

    def list_data_source_sync_jobs(
        self, **kwargs: Unpack[ListDataSourceSyncJobsRequestTypeDef]
    ) -> ListDataSourceSyncJobsResponseTypeDef:
        """
        Get information about an Amazon Q Business data source connector
        synchronization.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_data_source_sync_jobs.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_data_source_sync_jobs)
        """

    def list_data_sources(
        self, **kwargs: Unpack[ListDataSourcesRequestTypeDef]
    ) -> ListDataSourcesResponseTypeDef:
        """
        Lists the Amazon Q Business data source connectors that you have created.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_data_sources.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_data_sources)
        """

    def list_documents(
        self, **kwargs: Unpack[ListDocumentsRequestTypeDef]
    ) -> ListDocumentsResponseTypeDef:
        """
        A list of documents attached to an index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_documents.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_documents)
        """

    def list_groups(self, **kwargs: Unpack[ListGroupsRequestTypeDef]) -> ListGroupsResponseTypeDef:
        """
        Provides a list of groups that are mapped to users.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_groups.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_groups)
        """

    def list_indices(
        self, **kwargs: Unpack[ListIndicesRequestTypeDef]
    ) -> ListIndicesResponseTypeDef:
        """
        Lists the Amazon Q Business indices you have created.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_indices.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_indices)
        """

    def list_messages(
        self, **kwargs: Unpack[ListMessagesRequestTypeDef]
    ) -> ListMessagesResponseTypeDef:
        """
        Gets a list of messages associated with an Amazon Q Business web experience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_messages.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_messages)
        """

    def list_plugin_actions(
        self, **kwargs: Unpack[ListPluginActionsRequestTypeDef]
    ) -> ListPluginActionsResponseTypeDef:
        """
        Lists configured Amazon Q Business actions for a specific plugin in an Amazon Q
        Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_plugin_actions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_plugin_actions)
        """

    def list_plugin_type_actions(
        self, **kwargs: Unpack[ListPluginTypeActionsRequestTypeDef]
    ) -> ListPluginTypeActionsResponseTypeDef:
        """
        Lists configured Amazon Q Business actions for any plugin type—both built-in
        and custom.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_plugin_type_actions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_plugin_type_actions)
        """

    def list_plugin_type_metadata(
        self, **kwargs: Unpack[ListPluginTypeMetadataRequestTypeDef]
    ) -> ListPluginTypeMetadataResponseTypeDef:
        """
        Lists metadata for all Amazon Q Business plugin types.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_plugin_type_metadata.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_plugin_type_metadata)
        """

    def list_plugins(
        self, **kwargs: Unpack[ListPluginsRequestTypeDef]
    ) -> ListPluginsResponseTypeDef:
        """
        Lists configured Amazon Q Business plugins.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_plugins.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_plugins)
        """

    def list_retrievers(
        self, **kwargs: Unpack[ListRetrieversRequestTypeDef]
    ) -> ListRetrieversResponseTypeDef:
        """
        Lists the retriever used by an Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_retrievers.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_retrievers)
        """

    def list_subscriptions(
        self, **kwargs: Unpack[ListSubscriptionsRequestTypeDef]
    ) -> ListSubscriptionsResponseTypeDef:
        """
        Lists all subscriptions created in an Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_subscriptions.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_subscriptions)
        """

    def list_tags_for_resource(
        self, **kwargs: Unpack[ListTagsForResourceRequestTypeDef]
    ) -> ListTagsForResourceResponseTypeDef:
        """
        Gets a list of tags associated with a specified resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_tags_for_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_tags_for_resource)
        """

    def list_web_experiences(
        self, **kwargs: Unpack[ListWebExperiencesRequestTypeDef]
    ) -> ListWebExperiencesResponseTypeDef:
        """
        Lists one or more Amazon Q Business Web Experiences.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/list_web_experiences.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#list_web_experiences)
        """

    def put_feedback(
        self, **kwargs: Unpack[PutFeedbackRequestTypeDef]
    ) -> EmptyResponseMetadataTypeDef:
        """
        Enables your end user to provide feedback on their Amazon Q Business generated
        chat responses.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/put_feedback.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#put_feedback)
        """

    def put_group(self, **kwargs: Unpack[PutGroupRequestTypeDef]) -> Dict[str, Any]:
        """
        Create, or updates, a mapping of users—who have access to a document—to groups.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/put_group.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#put_group)
        """

    def search_relevant_content(
        self, **kwargs: Unpack[SearchRelevantContentRequestTypeDef]
    ) -> SearchRelevantContentResponseTypeDef:
        """
        Searches for relevant content in a Amazon Q Business application based on a
        query.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/search_relevant_content.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#search_relevant_content)
        """

    def start_data_source_sync_job(
        self, **kwargs: Unpack[StartDataSourceSyncJobRequestTypeDef]
    ) -> StartDataSourceSyncJobResponseTypeDef:
        """
        Starts a data source connector synchronization job.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/start_data_source_sync_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#start_data_source_sync_job)
        """

    def stop_data_source_sync_job(
        self, **kwargs: Unpack[StopDataSourceSyncJobRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Stops an Amazon Q Business data source connector synchronization job already in
        progress.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/stop_data_source_sync_job.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#stop_data_source_sync_job)
        """

    def tag_resource(self, **kwargs: Unpack[TagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Adds the specified tag to the specified Amazon Q Business application or data
        source resource.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/tag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#tag_resource)
        """

    def untag_resource(self, **kwargs: Unpack[UntagResourceRequestTypeDef]) -> Dict[str, Any]:
        """
        Removes a tag from an Amazon Q Business application or a data source.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/untag_resource.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#untag_resource)
        """

    def update_application(
        self, **kwargs: Unpack[UpdateApplicationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Updates an existing Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_application.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_application)
        """

    def update_chat_controls_configuration(
        self, **kwargs: Unpack[UpdateChatControlsConfigurationRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Updates a set of chat controls configured for an existing Amazon Q Business
        application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_chat_controls_configuration.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_chat_controls_configuration)
        """

    def update_data_accessor(
        self, **kwargs: Unpack[UpdateDataAccessorRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Updates an existing data accessor.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_data_accessor.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_data_accessor)
        """

    def update_data_source(
        self, **kwargs: Unpack[UpdateDataSourceRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Updates an existing Amazon Q Business data source connector.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_data_source.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_data_source)
        """

    def update_index(self, **kwargs: Unpack[UpdateIndexRequestTypeDef]) -> Dict[str, Any]:
        """
        Updates an Amazon Q Business index.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_index.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_index)
        """

    def update_plugin(self, **kwargs: Unpack[UpdatePluginRequestTypeDef]) -> Dict[str, Any]:
        """
        Updates an Amazon Q Business plugin.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_plugin.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_plugin)
        """

    def update_retriever(self, **kwargs: Unpack[UpdateRetrieverRequestTypeDef]) -> Dict[str, Any]:
        """
        Updates the retriever used for your Amazon Q Business application.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_retriever.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_retriever)
        """

    def update_subscription(
        self, **kwargs: Unpack[UpdateSubscriptionRequestTypeDef]
    ) -> UpdateSubscriptionResponseTypeDef:
        """
        Updates the pricing tier for an Amazon Q Business subscription.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_subscription.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_subscription)
        """

    def update_user(self, **kwargs: Unpack[UpdateUserRequestTypeDef]) -> UpdateUserResponseTypeDef:
        """
        Updates a information associated with a user id.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_user.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_user)
        """

    def update_web_experience(
        self, **kwargs: Unpack[UpdateWebExperienceRequestTypeDef]
    ) -> Dict[str, Any]:
        """
        Updates an Amazon Q Business web experience.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/update_web_experience.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#update_web_experience)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["get_chat_controls_configuration"]
    ) -> GetChatControlsConfigurationPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_applications"]
    ) -> ListApplicationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_attachments"]
    ) -> ListAttachmentsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_conversations"]
    ) -> ListConversationsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_data_accessors"]
    ) -> ListDataAccessorsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_data_source_sync_jobs"]
    ) -> ListDataSourceSyncJobsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_data_sources"]
    ) -> ListDataSourcesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_documents"]
    ) -> ListDocumentsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_groups"]
    ) -> ListGroupsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_indices"]
    ) -> ListIndicesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_messages"]
    ) -> ListMessagesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_plugin_actions"]
    ) -> ListPluginActionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_plugin_type_actions"]
    ) -> ListPluginTypeActionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_plugin_type_metadata"]
    ) -> ListPluginTypeMetadataPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_plugins"]
    ) -> ListPluginsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_retrievers"]
    ) -> ListRetrieversPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_subscriptions"]
    ) -> ListSubscriptionsPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["list_web_experiences"]
    ) -> ListWebExperiencesPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """

    @overload  # type: ignore[override]
    def get_paginator(  # type: ignore[override]
        self, operation_name: Literal["search_relevant_content"]
    ) -> SearchRelevantContentPaginator:
        """
        Create a paginator for an operation.

        [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/qbusiness/client/get_paginator.html)
        [Show types-boto3 documentation](https://youtype.github.io/types_boto3_docs/types_boto3_qbusiness/client/#get_paginator)
        """
